==> infinite_scroll_list_view-0.0.3.tar.gz: example/example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:infinite_scroll_list_view/infinite_scroll_list_view.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  final key = GlobalKey<InfiniteScrollListViewState<String>>();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: InfiniteScrollListView<String>(
        key: key,
        pageLoader: getPage,
        elementBuilder: (val, anim) => ListTile(
          title: Text(val),
          trailing: IconButton(
            icon: Icon(Icons.clear),
            onPressed: () => remove(val),
          ),
        ),
      ),
      // This trailing comma makes auto-formatting nicer for build methods.
    );
  }

  void remove(String id) {
    key.currentState!.removeWere((value) => value == id);
  }

  Future<List<String>> getPage(int index) async {
    if (index == 0) {
      return ["a", "b", "c", "c", "d"];
    }
    return [];
  }
}

==> infinite_scroll_list_view-0.0.4.tar.gz: example/example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:infinite_scroll_list_view/infinite_scroll_list_view.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  final key = GlobalKey<InfiniteScrollListViewState<String>>();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: InfiniteScrollListView<String>(
        key: key,
        pageLoader: getPage,
        elementBuilder: (val, anim) => ListTile(
          title: Text(val),
          trailing: IconButton(
            icon: Icon(Icons.clear),
            onPressed: () => remove(val),
          ),
        ),
      ),
      // This trailing comma makes auto-formatting nicer for build methods.
    );
  }

  void remove(String id) {
    key.currentState!.removeWere((value) => value == id);
  }

  Future<List<String>?> getPage(int index) async {
    if (index == 0) {
      return null;
    }
    return null;
  }
}
